'use strict';

var app = require('~/cartridge/scripts/app');
var guard = require('~/cartridge/scripts/guard');

/* API Includes */
var Cart = require('~/cartridge/scripts/models/CartModel');
var PaymentMgr = require('dw/order/PaymentMgr');
var OrderMgr = require('dw/order/OrderMgr');
var Transaction = require('dw/system/Transaction');
var URLUtils = require('dw/web/URLUtils');

var libPayment = require('int_payment_core/cartridge/scripts/lib/libPayment.ds')
var parameterMap = request.httpParameterMap;
/**
 * Used to place a redirect to Payment.
 */
function Authorize(args) {
	
	var dwutil = require('dw/util');
	var res, Enable3DS;
	var orderNo = args.OrderNo;
    var paymentInstrument = args.PaymentInstrument;
    var order = OrderMgr.getOrder(args.OrderNo);
    
    if(customer.authenticated) {
    	var creditCards = customer.profile.wallet.getPaymentInstruments();
    } else {
    	var creditCards = new dwutil.ArrayList();
    }
    Transaction.wrap(function () {
    	Enable3DS = libPayment.Is3DSEnabled(order);
    });
	var cardCvn = session.forms.billing.paymentMethods.creditCard.cvn.value
	session.forms.billing.paymentMethods.selectedPaymentMethodID.value = "CREDIT_CARD";
	Transaction.wrap(function () {
		res = libPayment.SendHostedTokenizationCreditCardAuthorization(order, Enable3DS, dw.order.PaymentInstrument.METHOD_CREDIT_CARD, request.locale, customer);
	});
    if(res.success) {
	    Transaction.wrap(function () {
			paymentInstrument.paymentTransaction.transactionID = res.PayID;
			paymentInstrument.paymentTransaction.paymentProcessor = PaymentMgr.getPaymentMethod(res.PaymentMethodIDOut).getPaymentProcessor()
			paymentInstrument.paymentTransaction.custom.paymentStatus = res.Status;
			paymentInstrument.custom.paymentMethod = res.PaymentMethod;
			paymentInstrument.creditCardType = res.Brand;
	    });
	    if(!res.Enrolled) {
	    	return {authorized: true};
	    } else {
	    	if(!empty(res.HTML)) {
				session.custom.PaymentProcessStarted = null;
				return Redirect({
					HTML : res.HTML,
					Order : order,
					PaymentMethodID : res.PaymentMethodIDOut					
				});
	    	} else {
	    		return {error: true};
	    	}
	    }
	} else {
		if(res.ResultStatusCheck == "RETRY"){
			return {authorized: true}
		} else {
			return {error: true}
		}
	}    
}

/**
 * Verifies a credit card against a valid card number and expiration date and possibly invalidates invalid form fields. If the verification was successful a credit card payment instrument is created.
 */
function Handle(args) {
	var paymentInstrument;
	if(args.Basket == null || session.forms.billing.paymentMethods.selectedPaymentMethodID.value == null){
		return {error: true};
	}

	var cart = app.getModel('Cart').get(args.Basket);
	var paymentType = session.forms.billing.paymentMethods.selectedPaymentMethodID.value;
	
	if(session.custom.hostedTokenizationSucces) {
		Transaction.wrap(function () {
			cart.removeExistingPaymentInstruments(paymentType);
			paymentInstrument = cart.createPaymentInstrument(paymentType, cart.getNonGiftCertificateAmount());
	    });
		return {success: true};
	} else {
		return {error: true};	
	}
}


/**
 * Redirect to Payment 3DS authentification page
 */
function Redirect(args) {
	var Resource = require('dw/web/Resource');
	if(empty(session.custom.PaymentProcessStarted)) {
		if(!empty(args.HTML)){
			var res = libPayment.GetPaymentRequestParameters(args.Order, request, args.PaymentMethodID);
			if(res.success) {
				var PaymentRequestParameters = res.PaymentRequestParameters;
			} else {
				session.custom.PaymentProcessStarted = null;
				app.getController('COBilling').Start();
				return {error: true};
			}
			session.custom.PaymentProcessStarted = 'true';
	        var pageMeta = require('~/cartridge/scripts/meta');
	        pageMeta.update({pageTitle: Resource.msg('checkout.pages.redirect', 'checkout', 'SiteGenesis Checkout')});
	        app.getView({
	        	HTML : args.HTML,
	        	PaymentRequestParameters : PaymentRequestParameters
	        }).render('paymentredirect');
	        return {authorized: true};
		}
		
	} else {
		session.custom.PaymentProcessStarted = null;
		app.getController('COBilling').Start();
		return {error: true};
	}
}

exports.Authorize = Authorize;
exports.Handle = Handle;
